function graph_M1d(handle)
%
%GRAPH_M1D
%
%       Graph the data in the 1D mode.
%

global ParsecData WFNData pvoxM1d PguiData

axes(handle);

% Find Atom Locations
x1 = pvoxM1d.point_1(1);
y1 = pvoxM1d.point_1(2);
z1 = pvoxM1d.point_1(3);
x2 = pvoxM1d.point_2(1);
y2 = pvoxM1d.point_2(2);
z2 = pvoxM1d.point_2(3);
dx = x2-x1;
dy = y2-y1;
dz = z2-z1;
dist = sqrt((x2-x1)^2 + (y2-y1)^2 + (z2-z1)^2);

if ( PguiData.draw_mode == 1 )
    set(handle, 'DrawMode', 'normal');
else
    set(handle, 'DrawMode', 'fast');
end

if (pvoxM1d.atomview == 1)
    %% --- Plots line connecting Atoms --- %%

    % Save view and plot line between atoms
    hold off;
    plot3([x1, x2], [y1, y2], [z1, z2]);
    plot_atoms;
    grid on;
    %% --- Plots line connecting Atoms --- %%

elseif (pvoxM1d.atomview == 0 && dist ~= 0)
    %% --- Plot WFN --- %%

    %update atom names
    atom1 = get(pvoxM1d.pulldown_1, 'Value');
    atom2 = get(pvoxM1d.pulldown_2, 'Value');
    if (atom1 <= ParsecData.num_atoms)
        atom1Name = ['_' mat2str(atom1) mat2str(ParsecData.atomName(atom1,:))];
    else
        atom1Name = [get(pvoxM1d.edit_1,'String') ' '];
    end
    if (atom2 <= ParsecData.num_atoms)
        atom2Name = ['_' mat2str(atom2) mat2str(ParsecData.atomName(atom2,:))];
    else
        atom2Name = [get(pvoxM1d.edit_1,'String') ' '];
    end

    % Find clipping region for line
    tix = NaN; tiy = NaN; tiz = NaN;
    tfx = NaN; tfy = NaN; tfz = NaN;
    
    if (dx ~= 0)
        tix = min([(-1*WFNData.radius - (x1+dx/2)) / (dx/2), (WFNData.radius-WFNData.step - (x1+dx/2)) / (dx/2)]);
        tfx = max([(-1*WFNData.radius - (x1+dx/2)) / (dx/2), (WFNData.radius-WFNData.step - (x1+dx/2)) / (dx/2)]);
    end
    
    if (dy ~= 0)
        tiy = min([(-1*WFNData.radius - (y1+dy/2)) / (dy/2), (WFNData.radius-WFNData.step - (y1+dy/2)) / (dy/2)]);
        tfy = max([(-1*WFNData.radius - (y1+dy/2)) / (dy/2), (WFNData.radius-WFNData.step - (y1+dy/2)) / (dy/2)]);
    end
    
    if (dz ~= 0)
        tiz = min([(-1*WFNData.radius - (z1+dz/2)) / (dz/2), (WFNData.radius-WFNData.step - (z1+dz/2)) / (dz/2)]);
        tfz = max([(-1*WFNData.radius - (z1+dz/2)) / (dz/2), (WFNData.radius-WFNData.step - (z1+dz/2)) / (dz/2)]);
    end
    
    ti = max([tix, tiy, tiz]);
    tf = min([tfx, tfy, tfz]);

    % Determine t step size
    dt = WFNData.step / max(abs([dx/2, dy/2, dz/2]));
    ti = ti + dt;
    tf = tf - dt;
    dt = dt/4;
    t_map = (ti:dt:tf);

    f = [];
    g = [];
    vec_x = (dx/2).*t_map + (x1+dx/2);
    vec_y = (dy/2).*t_map + (y1+dy/2);
    vec_z = (dz/2).*t_map + (z1+dz/2);
    
    % Interpolate along line
    switch PguiData.graph
        case 'wfn'
            f = interp3(WFNData.X, WFNData.Y, WFNData.Z, WFNData.wfn(:,:,:,pvoxM1d.level),vec_x,vec_y,vec_z,'*linear');
            
        case 'pot'
            f = interp3(WFNData.X, WFNData.Y, WFNData.Z, WFNData.pot(:,:,:),vec_x,vec_y,vec_z,'*linear');
            
        case 'rho'
            f = interp3(WFNData.X, WFNData.Y, WFNData.Z, WFNData.rho(:,:,:),vec_x,vec_y,vec_z,'*linear');
    end

    % Plot WFN
    hold off;
    plot(t_map*(dist/2),f);
    
    % Set scale
    switch PguiData.graph
        case 'wfn'
            if (PguiData.wfn_universal)
                pvoxM1d.wfn_scale = [ti*dist/2 tf*dist/2 0 pvoxM1d.wfn_max];
            else
                pvoxM1d.wfn_scale = [ti*dist/2 tf*dist/2 0 max(f)];
            end
            scale = pvoxM1d.wfn_scale;
        case 'pot'
            pvoxM1d.pot_scale = [ti*dist/2 tf*dist/2 min(f) pvoxM1d.pot_max];
            scale = pvoxM1d.pot_scale;
        case 'rho'
            pvoxM1d.rho_scale = [ti*dist/2 tf*dist/2 0 pvoxM1d.rho_max];
            scale = pvoxM1d.rho_scale;
    end
    axis(scale);
    
    % Plot atom locations
    hold on;
    atomX = [dist/2, dist/2];
    atomY = [scale(3), scale(4)];
    plot(atomX,atomY,'--r');
    plot(-atomX,atomY,'--r');
    hold off;

    % Label Plot
    xlabel('distance (bohr)');
    titleString = [atom1Name ' (d = -' mat2str(dist/2,3) ')   and  '];
    titleString = [titleString atom2Name ' (d = ' mat2str(dist/2,3) ')'];
    title(titleString);

    %% --- Plot WFN --- %%
else
    %ASSERT: DIST ~= 0
    beep
end

if ( PguiData.draw_mode == 1 )
    set(handle, 'DrawMode', 'normal');
else
    set(handle, 'DrawMode', 'fast');
end
