function update_M1d(string,varargin)
%
%UPDATE_M1D
%
%       1D specific update function, updates the control values and 
%       positions based on the input string, and possibly the value 
%       passed in as well. Then it calls update_state to update the 
%       user state (rotatation, colorbar, etc.)
%
%

global pvoxM1d PguiData ParsecData WFNData Ptoolbar Phandles;

if (pvoxM1d.atomview)
    zoom(Phandles.figure1, 'reset');
end

switch string
    case 'pulldown_1'
        %update the first point based on the pulldown
        
        old_point = pvoxM1d.point_1;
        old_atom = pvoxM1d.atom_1;
        pvoxM1d.atom_1 = varargin{1};
        if (pvoxM1d.atom_1 <= ParsecData.num_atoms)
            pvoxM1d.point_1 = [ParsecData.forceTotal(pvoxM1d.atom_1,1), ParsecData.forceTotal(pvoxM1d.atom_1,2), ParsecData.forceTotal(pvoxM1d.atom_1,3)];
            set(pvoxM1d.edit_1, 'String', ['(' mat2str(pvoxM1d.point_1(1),3) ',' mat2str(pvoxM1d.point_1(2),3) ',' mat2str(pvoxM1d.point_1(3),3) ')']);
        end
        if ( max(abs(pvoxM1d.point_1-pvoxM1d.point_2)) < .005 )
            pvoxM1d.point_2 = old_point;
            pvoxM1d.atom_2 = old_atom;
            set(pvoxM1d.edit_2, 'String', ['(' mat2str(old_point(1),3) ',' mat2str(old_point(2),3) ',' mat2str(old_point(3),3) ')']);
            set(pvoxM1d.pulldown_2, 'Value', old_atom);
        end
        graph_M1d(pvoxM1d.axes);

    case 'pulldown_2'
        %update the second point based on the pulldown

        old_point = pvoxM1d.point_2;
        old_atom = pvoxM1d.atom_2;
        pvoxM1d.atom_2 = varargin{1};
        if (pvoxM1d.atom_2 <= ParsecData.num_atoms)
            pvoxM1d.point_2 = [ParsecData.forceTotal(pvoxM1d.atom_2,1), ParsecData.forceTotal(pvoxM1d.atom_2,2), ParsecData.forceTotal(pvoxM1d.atom_2,3)];
            set(pvoxM1d.edit_2, 'String', ['(' mat2str(pvoxM1d.point_2(1),3) ',' mat2str(pvoxM1d.point_2(2),3) ',' mat2str(pvoxM1d.point_2(3),3) ')']);
        end
        if ( max(abs(pvoxM1d.point_1-pvoxM1d.point_2)) < .005 )
            pvoxM1d.point_1 = old_point;
            pvoxM1d.atom_1 = old_atom;
            set(pvoxM1d.edit_1, 'String', ['(' mat2str(old_point(1),3) ',' mat2str(old_point(2),3) ',' mat2str(old_point(3),3) ')']);
            set(pvoxM1d.pulldown_1, 'Value', old_atom);
        end
        graph_M1d(pvoxM1d.axes);


    case 'edit_1'
        %update the first point based on the user string
        
        old_point = pvoxM1d.point_1;
        old_atom = pvoxM1d.atom_1;
        input = varargin{1};
        [pvoxM1d.point_1,valid] = parse_edit(input);
        if (~valid)
            pvoxM1d.point_1 = old_point;
            set(pvoxM1d.pulldown_1,'Value', old_atom);
        else
            pvoxM1d.atom_1 = ParsecData.num_atoms+1;
            set(pvoxM1d.pulldown_1,'Value', pvoxM1d.atom_1);
            if ( max(abs(pvoxM1d.point_1-pvoxM1d.point_2)) < .005 )
                pvoxM1d.point_2 = old_point;
                pvoxM1d.atom_2 = old_atom;
                set(pvoxM1d.edit_2, 'String', ['(' mat2str(old_point(1),3) ',' mat2str(old_point(2),3) ',' mat2str(old_point(3),3) ')']);
                set(pvoxM1d.pulldown_2, 'Value', old_atom);
            end
            graph_M1d(pvoxM1d.axes);
        end
        set(pvoxM1d.edit_1,'String',['(' mat2str(pvoxM1d.point_1(1),3) ',' mat2str(pvoxM1d.point_1(2),3) ',' mat2str(pvoxM1d.point_1(3),3) ')']);
        %drawnow;

    case 'edit_2'
        %update the first point based on the user string

        old_point = pvoxM1d.point_2;
        old_atom = pvoxM1d.atom_2;
        input = varargin{1};
        [pvoxM1d.point_2,valid] = parse_edit(input);
        if (~valid)
            pvoxM1d.point_2 = old_point;
            set(pvoxM1d.pulldown_1,'Value', old_atom);
        else
            pvoxM1d.atom_2 = ParsecData.num_atoms+1;
            set(pvoxM1d.pulldown_2,'Value', pvoxM1d.atom_2);
            if ( max(abs(pvoxM1d.point_1-pvoxM1d.point_2)) < .005 )
                pvoxM1d.point_1 = old_point;
                pvoxM1d.atom_1 = old_atom;
                set(pvoxM1d.edit_1, 'String', ['(' mat2str(old_point(1),3) ',' mat2str(old_point(2),3) ',' mat2str(old_point(3),3) ')']);
                set(pvoxM1d.pulldown_1, 'Value', old_atom);
            end
            graph_M1d(pvoxM1d.axes);
        end
        set(pvoxM1d.edit_2,'String',['(' mat2str(pvoxM1d.point_2(1),3) ',' mat2str(pvoxM1d.point_2(2),3) ',' mat2str(pvoxM1d.point_2(3),3) ')']);
        %drawnow;

    case 'slider_level'
        %update which energy level of wavefunction to display

        val = round( varargin{1} *(WFNData.num_states-1)+1 );

        if ~(pvoxM1d.level == val)
            pvoxM1d.level=val;
            graph_M1d(pvoxM1d.axes);
        end
        
        set(pvoxM1d.slider_level,'Value', (pvoxM1d.level-1)/(WFNData.num_states-1) );
        set(pvoxM1d.edit_level,'String', mat2str(pvoxM1d.level + WFNData.first_state - 1, 4 ) );


    case 'edit_level'
        %update which energy level of wavefunction to display

        val = round( str2num( varargin{1} ) );

        if (max(size(val))==1) && isreal(val) && (val ~= pvoxM1d.level) && (val >= 1)

            if (val > WFNData.num_states)
                pvoxM1d.level = WFNData.num_states;
            else
                pvoxM1d.level = val;
            end
            graph_M1d(pvoxM1d.axes);
        end

        set(pvoxM1d.slider_level,'Value', (pvoxM1d.level-1)/(WFNData.num_states-1) );
        set(pvoxM1d.edit_level,'String', mat2str(pvoxM1d.level + WFNData.first_state - 1, 4 ) );


    case 'atomview'
        %update whether to display the line (along with the atoms)
        %or the data along the line
        
        if varargin{1}
            view(PguiData.az, PguiData.el);
            pvoxM1d.atomview=1;
            set(Ptoolbar.rotate,'Enable','on');
            set(pvoxM1d.toggle_atoms,'Value',get(pvoxM1d.toggle_atoms,'Max') );
            set(pvoxM1d.toggle_plot,'Value',get(pvoxM1d.toggle_plot,'Min') );
        else
            [PguiData.az, PguiData.el] = view;
            pvoxM1d.atomview=0;
            set(Ptoolbar.rotate,'Enable','off');
            set(pvoxM1d.toggle_atoms,'Value',get(pvoxM1d.toggle_atoms,'Min') );
            set(pvoxM1d.toggle_plot,'Value',get(pvoxM1d.toggle_plot,'Max') );
        end

        graph_M1d(pvoxM1d.axes);
        
        
    case {'pot','rho','wfn'}
        %update controls for a change in graph
              
        switch PguiData.graph
            case 'wfn'
                set(Ptoolbar.wfn,'State','on');
                set(Ptoolbar.pot,'State','off');
                set(Ptoolbar.rho,'State','off');

                set(pvoxM1d.slider_level,'SliderStep', [ 1/(WFNData.num_states-1) 1/(WFNData.num_states-1) ] );

                set(pvoxM1d.slider_level,'Value', (pvoxM1d.level-1)/(WFNData.num_states-1) );
                set(pvoxM1d.edit_level,'String', mat2str(pvoxM1d.level + WFNData.first_state - 1, 4 ) );

            case 'pot'
                set(Ptoolbar.wfn,'State','off');
                set(Ptoolbar.pot,'State','on');
                set(Ptoolbar.rho,'State','off');
            case 'rho'
                set(Ptoolbar.wfn,'State','off');
                set(Ptoolbar.pot,'State','off');
                set(Ptoolbar.rho,'State','on');
            
        end

        if pvoxM1d.atomview
            set(Ptoolbar.rotate,'Enable','on');
            set(pvoxM1d.toggle_atoms,'Value',get(pvoxM1d.toggle_atoms,'Max') );
            set(pvoxM1d.toggle_plot,'Value',get(pvoxM1d.toggle_plot,'Min') );
        else
            set(Ptoolbar.rotate,'Enable','off');
            set(pvoxM1d.toggle_atoms,'Value',get(pvoxM1d.toggle_atoms,'Min') );
            set(pvoxM1d.toggle_plot,'Value',get(pvoxM1d.toggle_plot,'Max') );
        end

        graph_M1d(pvoxM1d.axes);
        
        global Phandles;
        zoom(Phandles.figure1, 'reset');
        
        
    case 'everything'
        %update all controls
              
        switch PguiData.graph
            case 'wfn'
                set(Ptoolbar.wfn,'State','on');
                set(Ptoolbar.pot,'State','off');
                set(Ptoolbar.rho,'State','off');

                set(pvoxM1d.slider_level,'SliderStep', [ 1/(WFNData.num_states-1) 1/(WFNData.num_states-1) ] );

                set(pvoxM1d.slider_level,'Value', (pvoxM1d.level-1)/(WFNData.num_states-1) );
                set(pvoxM1d.edit_level,'String', mat2str(pvoxM1d.level + WFNData.first_state - 1, 4 ) );

            case 'pot'
                set(Ptoolbar.wfn,'State','off');
                set(Ptoolbar.pot,'State','on');
                set(Ptoolbar.rho,'State','off');
            case 'rho'
                set(Ptoolbar.wfn,'State','off');
                set(Ptoolbar.pot,'State','off');
                set(Ptoolbar.rho,'State','on');
                
        end
        
        atomlist = {''};
        for m=(1:ParsecData.num_atoms)
            a = strcat( mat2str(m,2), '. ', ParsecData.atomName(m,:) );
            atomlist(m) = {a};
        end
        atomlist(m+1) = {[mat2str(m+1,2) '. User Defined']};
        set(pvoxM1d.pulldown_1,'String',atomlist);
        set(pvoxM1d.pulldown_2,'String',atomlist);

        pvoxM1d.point_1 = [ParsecData.forceTotal(1,1), ParsecData.forceTotal(1,2), ParsecData.forceTotal(1,3)];
        pvoxM1d.point_2 = [ParsecData.forceTotal(2,1), ParsecData.forceTotal(2,2), ParsecData.forceTotal(2,3)];
        set(pvoxM1d.pulldown_1, 'Value', 1);
        set(pvoxM1d.pulldown_2, 'Value', 2)
        set(pvoxM1d.edit_1,'String',['(' mat2str(pvoxM1d.point_1(1),3) ',' mat2str(pvoxM1d.point_1(2),3) ',' mat2str(pvoxM1d.point_1(3),3) ')']);
        set(pvoxM1d.edit_2,'String',['(' mat2str(pvoxM1d.point_2(1),3) ',' mat2str(pvoxM1d.point_2(2),3) ',' mat2str(pvoxM1d.point_2(3),3) ')']);

        if pvoxM1d.atomview
            set(Ptoolbar.rotate,'Enable','on');
            set(pvoxM1d.toggle_atoms,'Value',get(pvoxM1d.toggle_atoms,'Max') );
            set(pvoxM1d.toggle_plot,'Value',get(pvoxM1d.toggle_plot,'Min') );
        else
            set(Ptoolbar.rotate,'Enable','off');
            set(pvoxM1d.toggle_atoms,'Value',get(pvoxM1d.toggle_atoms,'Min') );
            set(pvoxM1d.toggle_plot,'Value',get(pvoxM1d.toggle_plot,'Max') );
        end

        graph_M1d(pvoxM1d.axes);


    otherwise
end

%update camera and user state
if (pvoxM1d.atomview)
    zoom(Phandles.figure1, 'out');
    axis(pvoxM1d.scale);
    axis square;
    zoom(Phandles.figure1, 'reset');
end

update_state;
