function graph_M3d(handle)
%
%GRAPH_M3D
%
%       Graph the data in the 3D mode.
%

global WFNData ParsecData PguiData pvoxM3d Phandles;

axes(handle);

set(Phandles.figure1, 'BackingStore', 'on');

% Get the grid of the wave function
X = WFNData.X(1,:,1);
Y = WFNData.Y(:,1,1);
Z = WFNData.Z(1,1,:);

% How many slices there are
slices = pvoxM3d.num_slices;

% Get the number of grid points, put in s
s = size(Y);
s = s(1);

if ( PguiData.draw_mode == 1 )
    set(handle, 'DrawMode', 'normal');
else
    set(handle, 'DrawMode', 'fast');
end

% Determine where the slices should be by splitting the grid evenly
X = X(round(s/(slices*2)):round(s/slices):s);
Y = Y(round(s/(slices*2)):round(s/slices):s);
Z = Z(round(s/(slices*2)):round(s/slices):s);

% Determine scale
switch( PguiData.graph )
    case 'wfn'
        pvoxM3d.wfn_scale = [-WFNData.radius WFNData.radius -WFNData.radius WFNData.radius -WFNData.radius WFNData.radius min(min(min(WFNData.wfn(:,:,:,pvoxM3d.level)))) max(max(max(WFNData.wfn(:,:,:,pvoxM3d.level))))];
        scale = pvoxM3d.wfn_scale;
        %scale(7) = min(min(min(WFNData.wfn(:,:,:,pvoxM3d.level))));
        %scale(8) = max(max(max(WFNData.wfn(:,:,:,pvoxM3d.level))));
    case 'pot'
        scale = pvoxM3d.pot_scale;
    case 'rho'
        scale = pvoxM3d.rho_scale;
end

% If color is set, draw the whole slice, otherwise draw contour lines
if (pvoxM3d.color)
    cla;
    hold on;
    set(handle, 'NextPlot', 'replacechildren');
    am = alphamap('rampup', 64);

    alpha('color');
    switch( PguiData.graph )
        case 'wfn'
            g = slice(WFNData.X, WFNData.Y, WFNData.Z, WFNData.wfn(:,:,:,pvoxM3d.level), X, Y, Z);
        case 'pot'
            g = slice(WFNData.X, WFNData.Y, WFNData.Z, WFNData.pot, X, Y, Z);
            % This changes the alphamap for the potential
            mi = min(min(min(WFNData.pot)));
            ma = max(max(max(WFNData.pot)));
            if ( mi <= 0 && ma >= 0 )
                left = round((abs(mi)/(ma-mi))*64);
                right = 64 - left;
                for ( i = 1:left )
                    am(i) = .75*(1 - i/left);
                end
                for ( i = 1:right )
                    am(left+i) = i/right;
                end
            end
        case 'rho'
            g = slice(WFNData.X, WFNData.Y, WFNData.Z, WFNData.rho, X, Y, Z);
    end
    % Make the less important parts transparent
    am = am .* 2/sqrt(slices);
    alpha('color');
    set(g, 'LineStyle', 'none');
    set(g, 'FaceColor', 'interp');
    %CD = get(g, 'CData');
    %CD = cell2mat(CD);
    %CD = rgb2ind(CD, 64);
    %set(g, 'AlphaDataMapping', 'scaled');
    %set(g, 'FaceAlpha', 'interp');
    %set(g, 'AlphaData', CD);
    set(g, 'AlphaDataMapping', 'scaled');
    set(g, 'FaceAlpha', 'interp');
    %set(g, 'FaceColor', 'interp', 'FaceAlpha', 'interp', 'AlphaDataMapping', 'scaled');
    set(Phandles.figure1, 'Alphamap', am);
    hold off;
else
    cla
    set(handle, 'NextPlot', 'replacechildren');
    s1 = size(PguiData.contour_levels(:));
    if ( s1(1) == 1 )
        contour_levels = [PguiData.contour_levels;PguiData.contour_levels];
    else
        contour_levels = PguiData.contour_levels;
    end
    if ( s1(1) >= 1 )
        switch( PguiData.graph )
            case 'wfn'
                g = contourslice(WFNData.X, WFNData.Y, WFNData.Z, WFNData.wfn(:,:,:,pvoxM3d.level), X, Y, Z, contour_levels .* (scale(8)-scale(7)) + scale(7));
                %g = contourslice(WFNData.X, WFNData.Y, WFNData.Z, WFNData.wfn(:,:,:,pvoxM3d.level), X, Y, Z, contour_levels .* (scale(8)-scale(7)) + scale(7));
            case 'pot'
                g = contourslice(WFNData.X, WFNData.Y, WFNData.Z, WFNData.pot(:,:,:), X, Y, Z, contour_levels .* (scale(8)-scale(7)) + scale(7));
            case 'rho'
                g = contourslice(WFNData.X, WFNData.Y, WFNData.Z, WFNData.rho(:,:,:), X, Y, Z, contour_levels .* (scale(8)-scale(7)) + scale(7));
        end
    end
end


% Plot the atoms if necessary
if (PguiData.atoms)
    plot_atoms;
end


set(handle, 'ALim', [scale(7) scale(8) ]);

set(handle,'Box','off');
set(handle,'XGrid','on');
set(handle,'YGrid','on');
set(handle,'ZGrid','on');

% Change the colormap based on the preference
colormap(PguiData.colormap);
if ( PguiData.colormap_invert )
    cm = colormap;
    s = size(cm(:,1));
    s = s(1);
    for ( i = 1:s )
        cm2(i,:) = cm(s-i+1,:);
    end
    colormap(cm2);
end

if ( PguiData.draw_mode == 1 )
    set(handle, 'DrawMode', 'normal');
else
    set(handle, 'DrawMode', 'fast');
end
