function update_M3d(string,varargin)
%
%UPDATE_M3D
%
%       3D specific update function, updates the control values and 
%       positions based on the input string, and possibly the value 
%       passed in as well. Then it calls update_state to update the 
%       user state (rotatation, colorbar, etc.)
%
%

global pvoxM3d PguiData ParsecData WFNData Ptoolbar Phandles;

zoom(Phandles.figure1, 'reset');

switch string
    case 'atoms'
        %update whether to plot atoms
        
        graph_M3d(pvoxM3d.axes);
        
        
    case 'slider_level'
        %update which energy level of wavefunction to display
        
        val = round( varargin{1} *(WFNData.num_states-1)+1 );

        if ~(pvoxM3d.level == val)
            pvoxM3d.level=val;
            graph_M3d(pvoxM3d.axes);
        end

        set(pvoxM3d.slider_level,'Value', (pvoxM3d.level-1)/(WFNData.num_states-1) );
        set(pvoxM3d.edit_level,'String', mat2str(pvoxM3d.level + WFNData.first_state - 1, 4 ) );

        set(pvoxM3d.edit_energy,'String', mat2str( ParsecData.EigenvalueEV(pvoxM3d.level + WFNData.first_state - 1,ParsecData.num_iterations), 4 ) );
        

    case 'edit_level'
        %update which energy level of wavefunction to display

        val = round( str2num( varargin{1} ) );

        if (max(size(val))==1) && isreal(val) && (val ~= pvoxM3d.level) && (val >= 1)

            if (val > WFNData.num_states)
                pvoxM3d.level = WFNData.num_states;
            else
                pvoxM3d.level = val;
            end
            graph_M3d(pvoxM3d.axes);
        end
        
        set(pvoxM3d.slider_level,'Value', (pvoxM3d.level-1)/(WFNData.num_states-1) );
        set(pvoxM3d.edit_level,'String', mat2str(pvoxM3d.level + WFNData.first_state - 1, 4 ) );

        set(pvoxM3d.edit_energy,'String', mat2str( ParsecData.EigenvalueEV(pvoxM3d.level + WFNData.first_state - 1,ParsecData.num_iterations), 4 ) );
        
        
    case 'edit_num_slices'
        %update the number of slices to display
        
        val = round( str2num( varargin{1} ) );

        if (max(size(val))==1) && isreal(val) && ~(pvoxM3d.num_slices == val) && (val>=1)

            if (val <= WFNData.n)
                pvoxM3d.num_slices = val;
            else
                pvoxM3d.num_slices = WFNData.n;
            end
            graph_M3d(pvoxM3d.axes);
        end

        set(pvoxM3d.edit_num_slices,'String',mat2str(pvoxM3d.num_slices, 4 ) );


    case 'color'
        %update whether to display the color or contour graph
        
        drawnow;
        if ~( varargin{1} )
            pvoxM3d.color=0;
            set(pvoxM3d.toggle_contour,'Value',get(pvoxM3d.toggle_contour,'Max') );
            set(pvoxM3d.toggle_color,'Value',get(pvoxM3d.toggle_color,'Min') );
        else
            pvoxM3d.color=1;
            set(pvoxM3d.toggle_contour,'Value',get(pvoxM3d.toggle_contour,'Min') );
            set(pvoxM3d.toggle_color,'Value',get(pvoxM3d.toggle_color,'Max') );
        end
              
        graph_M3d(pvoxM3d.axes);        
        
    case {'pot','rho','wfn','everything'}
        %update all controls for change of graph or mode

        graph_M3d(pvoxM3d.axes);
        
        set(pvoxM3d.edit_num_slices,'String',mat2str(pvoxM3d.num_slices, 4 ) );

        switch PguiData.graph
            case 'wfn'
                set(Ptoolbar.wfn,'State','on');
                set(Ptoolbar.pot,'State','off');
                set(Ptoolbar.rho,'State','off');

                set(pvoxM3d.slider_level,'SliderStep', [ 1/(WFNData.num_states-1) 1/(WFNData.num_states-1) ] );
                
                set(pvoxM3d.edit_energy,'String', mat2str( ParsecData.EigenvalueEV(pvoxM3d.level + WFNData.first_state - 1,ParsecData.num_iterations), 4 ) );
        
                set(pvoxM3d.slider_level,'Value', (pvoxM3d.level-1)/(WFNData.num_states-1) );
                set(pvoxM3d.edit_level,'String', mat2str(pvoxM3d.level + WFNData.first_state - 1, 4 ) );

            case 'pot'
                set(Ptoolbar.wfn,'State','off');
                set(Ptoolbar.pot,'State','on');
                set(Ptoolbar.rho,'State','off');
            case 'rho'
                set(Ptoolbar.wfn,'State','off');
                set(Ptoolbar.pot,'State','off');
                set(Ptoolbar.rho,'State','on');
        end
        
        if ~(pvoxM3d.color)
            set(pvoxM3d.toggle_contour,'Value',get(pvoxM3d.toggle_contour,'Max') );
            set(pvoxM3d.toggle_color,'Value',get(pvoxM3d.toggle_color,'Min') );
        else
            set(pvoxM3d.toggle_contour,'Value',get(pvoxM3d.toggle_contour,'Min') );
            set(pvoxM3d.toggle_color,'Value',get(pvoxM3d.toggle_color,'Max') );
        end
        
        
    otherwise
end

%update camera and user state
zoom(Phandles.figure1, 'out');
switch( PguiData.graph )
    case 'wfn'
        axis(pvoxM3d.wfn_scale);
        if ( PguiData.wfn_universal == 1 )
            caxis([WFNData.wfn_min WFNData.wfn_max]);
        end
    case 'pot'
        axis(pvoxM3d.pot_scale);
    case 'rho'
        axis(pvoxM3d.rho_scale);
end
axis square;
zoom(Phandles.figure1, 'reset');

update_state;
