function update_Mslice(string,varargin)
%
%UPDATE_MSLICE
%
%       Slice specific update function, updates the control values and 
%       positions based on the input string, and possibly the value 
%       passed in as well. Then it calls update_state to update the 
%       user state (rotatation, colorbar, etc.)
%
%

global pvoxMslice PguiData ParsecData WFNData Ptoolbar Phandles;

zoom(Phandles.figure1, 'reset');

switch string
    case 'atoms'
        %update whether atoms are displayed
        
        graph_Mslice(pvoxMslice.axes);
        
        
    case 'slider_level'
        %update which energy level of wavefunction to display

        pvoxMslice.level = round( varargin{1} *(WFNData.num_states-1)+1 );

        graph_Mslice(pvoxMslice.axes);

        set(pvoxMslice.slider_level,'Value', (pvoxMslice.level-1)/(WFNData.num_states-1) );
        set(pvoxMslice.edit_level,'String', mat2str(pvoxMslice.level + WFNData.first_state - 1, 4 ) );

        set(pvoxMslice.toggle_energy,'String', mat2str( ParsecData.EigenvalueEV(pvoxMslice.level + WFNData.first_state - 1,ParsecData.num_iterations), 4 ) );
        
        if ( PguiData.wfn_universal == 1 )
            pvoxMslice.wfn_scale = [-WFNData.radius WFNData.radius -WFNData.radius WFNData.radius -WFNData.radius WFNData.radius WFNData.wfn_min WFNData.wfn_max];
        else
            pvoxMslice.wfn_scale = [-WFNData.radius WFNData.radius -WFNData.radius WFNData.radius -WFNData.radius WFNData.radius min(min(min(WFNData.wfn(:,:,:,pvoxMslice.level)))) max(max(max(WFNData.wfn(:,:,:,pvoxMslice.level))))];
        end
    case 'edit_level'
        %update which energy level of wavefunction to display

        val = round( str2num( varargin{1} ) );

        if (max(size(val))==1) && isreal(val) && (val >= 1) && (~(pvoxMslice.level == val))
            if val > WFNData.num_states
                pvoxMslice.level = WFNData.num_states;
            else
                pvoxMslice.level = val;
            end
            graph_Mslice(pvoxMslice.axes);
        end

        set(pvoxMslice.slider_level,'Value', (pvoxMslice.level-1)/(WFNData.num_states-1) );
        set(pvoxMslice.edit_level,'String', mat2str(pvoxMslice.level + WFNData.first_state - 1, 4 ) );

        set(pvoxMslice.toggle_energy,'String', mat2str( ParsecData.EigenvalueEV(pvoxMslice.level + WFNData.first_state - 1,ParsecData.num_iterations), 4 ) );


        if ( PguiData.wfn_universal == 1 )
            pvoxMslice.wfn_scale = [-WFNData.radius WFNData.radius -WFNData.radius WFNData.radius -WFNData.radius WFNData.radius WFNData.wfn_min WFNData.wfn_max];
        else
            pvoxMslice.wfn_scale = [-WFNData.radius WFNData.radius -WFNData.radius WFNData.radius -WFNData.radius WFNData.radius min(min(min(WFNData.wfn(:,:,:,pvoxMslice.level)))) max(max(max(WFNData.wfn(:,:,:,pvoxMslice.level))))];
        end
        
    case 'slider_x'
        %update x value

        val = round( varargin{1} *(WFNData.n-1)+1 );

        if ~(pvoxMslice.x == val)
            pvoxMslice.x=val;
            graph_Mslice(pvoxMslice.axes);
        end

        set(pvoxMslice.slider_x,'Value', (pvoxMslice.x-1)/(WFNData.n-1) );


    case 'slider_y'
        %update y value

        val = round( varargin{1} *(WFNData.n-1)+1 );

        if ~(pvoxMslice.y == val)
            pvoxMslice.y=val;
            graph_Mslice(pvoxMslice.axes);
        end

        set(pvoxMslice.slider_y,'Value', (pvoxMslice.y-1)/(WFNData.n-1) );


    case 'slider_z'
        %update z value

        val = round( varargin{1} *(WFNData.n-1)+1 );

        if ~(pvoxMslice.z == val)
            pvoxMslice.z=val;
            graph_Mslice(pvoxMslice.axes);
        end

        set(pvoxMslice.slider_z,'Value', (pvoxMslice.z-1)/(WFNData.n-1) );


    case {'pot','rho','wfn','everything'}
        %update all controls for change of graph or mode

        graph_Mslice(pvoxMslice.axes);
        
        step = [ 1/(WFNData.n-1) 1/(WFNData.n-1) ];

        set(pvoxMslice.slider_x,'SliderStep', step);
        set(pvoxMslice.slider_y,'SliderStep', step);
        set(pvoxMslice.slider_z,'SliderStep', step);

        set(pvoxMslice.slider_x,'Value', (pvoxMslice.x-1)/(WFNData.n-1) );
        set(pvoxMslice.slider_y,'Value', (pvoxMslice.y-1)/(WFNData.n-1) );
        set(pvoxMslice.slider_z,'Value', (pvoxMslice.z-1)/(WFNData.n-1) );

        set(pvoxMslice.toggle_energy,'String', mat2str( ParsecData.EigenvalueEV(pvoxMslice.level + WFNData.first_state - 1,ParsecData.num_iterations), 4 ) );

        switch PguiData.graph
            case 'wfn'
                set(Ptoolbar.wfn,'State','on');
                set(Ptoolbar.pot,'State','off');
                set(Ptoolbar.rho,'State','off');

                set(pvoxMslice.slider_level,'SliderStep', [ 1/(WFNData.num_states-1) 1/(WFNData.num_states-1) ] );

                set(pvoxMslice.slider_level,'Value', (pvoxMslice.level-1)/(WFNData.num_states-1) );
                set(pvoxMslice.edit_level,'String', mat2str(pvoxMslice.level + WFNData.first_state - 1, 4 ) );

            case 'pot'
                set(Ptoolbar.wfn,'State','off');
                set(Ptoolbar.pot,'State','on');
                set(Ptoolbar.rho,'State','off');
            case 'rho'
                set(Ptoolbar.wfn,'State','off');
                set(Ptoolbar.pot,'State','off');
                set(Ptoolbar.rho,'State','on');
        end

        if strcmp(string,'everything')
            if ( PguiData.wfn_universal == 1 )
                pvoxMslice.wfn_scale = [-WFNData.radius WFNData.radius -WFNData.radius WFNData.radius -WFNData.radius WFNData.radius WFNData.wfn_min WFNData.wfn_max];
            else
                pvoxMslice.wfn_scale = [-WFNData.radius WFNData.radius -WFNData.radius WFNData.radius -WFNData.radius WFNData.radius min(min(min(WFNData.wfn(:,:,:,pvoxMslice.level)))) max(max(max(WFNData.wfn(:,:,:,pvoxMslice.level))))];
            end
        end
        
    otherwise
end

%update camera and user state
zoom(Phandles.figure1, 'out');
switch( PguiData.graph )
    case 'wfn'
        axis(pvoxMslice.wfn_scale);
    case 'pot'
        axis(pvoxMslice.pot_scale);
    case 'rho'
        axis(pvoxMslice.rho_scale);
end
axis square;
zoom(Phandles.figure1, 'reset');

update_state;
