function [wfn, pot, rho, wavedata, XYZ] = wfnread(fileName, h)
%
%WFNREAD
%
%       reads wfn.dat from parsec
%

myFile = fopen(fileName,'r', 'l');

% Determine (big/little)-endian
prefix = fread(myFile, 1, 'uint32');
if (prefix > 100)
    fclose(myFile);
    myFile = fopen(fileName,'r', 'b');
    prefix = fread(myFile, 1, 'uint32');
end

date = fread(myFile, prefix, 'uchar');
date = (char(date'));
prefix = fread(myFile, 1, 'uint32');

%read in (wfn%Step, wfn%rmax, wfn%ndim, wfn%nwedge, i_1, i_1)
prefix = fread(myFile, 1, 'uint32');
wfn.step = fread(myFile, 1, 'double');
wfn.radius = fread(myFile, 1, 'double');
wfn.ndim = fread(myFile, 1, 'uint32');
wfn.num_wedges = fread(myFile, 1, 'uint32');
fread(myFile, 2, 'uint32'); % i_1's
prefix = fread(myFile, 1, 'uint32');

%read in (wfn%shift)
prefix = fread(myFile, 1, 'uint32');
wfn.shift = fread(myFile, prefix/8, 'double');
prefix = fread(myFile, 1, 'uint32');

%read in (i_1,kk=1,9)
prefix = fread(myFile, 1, 'uint32');
fread(myFile, prefix/4, 'uint32');  % i_1's
prefix = fread(myFile, 1, 'uint32');

%read in (one,kk=1,9)
prefix = fread(myFile, 1, 'uint32');
fread(myFile, prefix/8, 'double'); % one's
prefix = fread(myFile, 1, 'uint32');

%read in (one,kk=1,3)
prefix = fread(myFile, 1, 'uint32');
fread(myFile, prefix/8, 'double'); % one's
prefix = fread(myFile, 1, 'uint32');

%read in (zero,kk=1,9*3)
prefix = fread(myFile, 1, 'uint32');
fread(myFile, prefix/8, 'double'); % zero's
prefix = fread(myFile, 1, 'uint32');

%read in (i_1)
prefix = fread(myFile, 1, 'uint32');
fread(myFile, prefix/4, 'uint32');  % i_1
prefix = fread(myFile, 1, 'uint32');

%read in (wfn%kx(kk), wfn%ky(kk), wfn%kz(kk), kk=1, wfn%nwedge)
prefix = fread(myFile, 1, 'uint32');
if (prefix/4 ~= wfn.num_wedges*3);
    out =  'ERROR: reading wfn.k* from wfn.dat'
end
XYZ = fread(myFile, [3, wfn.num_wedges], 'int32');
XYZ = transpose(XYZ);
prefix = fread(myFile, 1, 'uint32');

%read in (nstate)
prefix = fread(myFile, 1, 'uint32');
wfn.num_states = fread(myFile, prefix/4, 'uint32');
prefix = fread(myFile, 1, 'uint32');

wfn.first_state = 1;

if (wfn.num_states > 35)
    global tmp_states first_tmp;
    tmp_states = wfn.num_states;
    uiwait(wfn_warning);
    wfn.first_state = first_tmp;
    wfn.num_states = tmp_states;
    clear global tmp_states first_tmp
end

%read in (i_1,kk=1,nstate)
prefix = fread(myFile, 1, 'uint32');
out = fread(myFile, prefix/4, 'uint32'); % i_1's
prefix = fread(myFile, 1, 'uint32');

%read in (en_tmp(kk),kk=1,nstate)
prefix = fread(myFile, 1, 'uint32');
wfn.en_tmp = fread(myFile, prefix/8, 'double');
prefix = fread(myFile, 1, 'uint32');

%read in (occ_tmp(kk),kk=1,nstate)
prefix = fread(myFile, 1, 'uint32');
wfn.occ_tmp = fread(myFile, prefix/8, 'double');
prefix = fread(myFile, 1, 'uint32');

%read in (pot%vnew(kk,1),kk=1,grid%nwedge)
prefix = fread(myFile, 1, 'uint32');
pot = fread(myFile, prefix/8, 'double');
prefix = fread(myFile, 1, 'uint32');

%read in (elec_st%rho(kk,1),kk=1,grid%nwedge)
prefix = fread(myFile, 1, 'uint32');
rho = fread(myFile, prefix/8, 'double');
prefix = fread(myFile, 1, 'uint32');

waitbar(0.5,h);

wavedata = zeros(wfn.num_wedges, wfn.num_states);
for (state = 1:wfn.num_states);
    prefix = fread(myFile, 1, 'uint32');
    wavedata(:,state) = fread(myFile, prefix/8, 'double');
    prefix = fread(myFile, 1, 'uint32');
end

fclose(myFile);
